@@ -250,18 +250,18 @@ class Clip(NewReferenceObject):
             notes.append(notation.do(expression, octave_shift))
 
         notes = standardize_notes(notes, scale, slot_duration, t_start)
-        repeats = len([ x for x in [ item for item in notes if len(item) ] if x[0] and x[0].repeat != 1])
+        #repeats = len([ x for x in [ item for item in notes if len(item) ] if x[0] and x.has_repeats()])
 
 
-        if repeats:
-            repeater = Transform(name=INTERNAL_REPEATER, slots=[1], octave_slots=None, divide=1, applies_to=BOTH, _repeat_processor=True)
-            notes = repeater.process(song, scale, self.track, notes, t_start, slot_duration)
+        #if repeats:
+        repeater = Transform(name=INTERNAL_REPEATER, slots=[1], octave_slots=None, divide=1, applies_to=BOTH, _repeat_processor=True)
+        notes = repeater.process(song, pattern, scale, self.track, notes, t_start, slot_duration)
 
         if transform:
             if type(transform) != list:
                 transform = [transform]
             for tform in transform:
-                notes  = tform.process(song, scale, self.track, notes, t_start, slot_duration)
+                notes  = tform.process(song, pattern, scale, self.track, notes, t_start, slot_duration)
 
         return notes
 
