@@ -18,16 +18,15 @@ NOTE_OFF = 0
 class Event(object):
 
 
-    __slots__ = [ 'type', 'note', 'time', 'on_event', 'off_event', 'scale' ]
+    __slots__ = [ 'type', 'note', 'time', 'on_event', 'scale' ]
 
     from . note import Note
 
-    def __init__(self, type=None, note=None, time=None, on_event=None, off_event=None, scale=None):
+    def __init__(self, type=None, note=None, time=None, on_event=None, scale=None, muted=False, track_copy=False):
         self.type = type
         self.note = note
         self.time = time
         self.on_event = on_event
-        self.off_event = off_event
         self.scale = scale
 
     def __repr__(self):
@@ -39,5 +38,5 @@ class Event(object):
             note = self.note.copy(), # could be a Chord!  Be careful.
             time = self.time,
             on_event = self.on_event,
-            off_event = self.off_event
+            scale = self.scale, # is this used?
         )
