@@ -48,9 +48,29 @@ MIDO_NOTE_OFF = 'note_off'
 from warpseq.model.chord import Chord
 from warpseq.model.event import Event, NOTE_OFF, NOTE_ON
 
+def _get_note_number(note, instrument):
+
+    max_o = instrument.max_octave
+    min_o = instrument.min_octave
+
+    note2 = note.transpose(octaves=instrument.base_octave)
+
+    if note2.octave > max_o:
+        note2.octave = max_o
+    if note2.octave < min_o:
+        note2.octave = min_o
+
+    nn = note2.note_number()
+
+    if nn < 0 or nn > 127:
+        raise InvalidNote()
+
+    return nn
+
+
 class RealtimeEngine(object):
 
-    __slots__ = ['song','track','clip','channel','device','midi_out','instrument','midi_port','mod_expressions','callbacks','on_count','player','on_ct']
+    __slots__ = ['song','track','clip','midi_out','midi_port','mod_expressions','callbacks','on_count','player','on_ct']
 
     def __init__(self, song=None, track=None, clip=None, player=None):
 
@@ -59,16 +79,12 @@ class RealtimeEngine(object):
         self.clip = clip
         self.on_ct = 0
 
-        self.instrument = self.track.instrument
-        self.channel = self.instrument.channel
-        self.device = self.instrument.device
+
         self.mod_expressions = ModExpression(defer=True, track=self.track, song=song)
 
         self.player = player
         self.callbacks = Callbacks()
 
-        self.midi_out = self.device.get_midi_out()
-
 
     def play(self, event):
 
@@ -117,35 +133,37 @@ class RealtimeEngine(object):
 
         if event.type == NOTE_ON:
 
+            # FIXME: assign note vs always redeferencing event.note
+
+
+
             velocity = event.note.velocity
             if velocity is None:
                 velocity = self.instrument.default_velocity
-            note_number = event.note.note_number()
 
             register_playing_note(self.track, event.note)
 
-            if event.note.octave > self.instrument.max_octave or note_number > 127:
-                return
-
-            if event.note.octave < self.instrument.min_octave or note_number < 0:
-                return
-
             for (control, value) in event.note.flags['cc'].items():
                 control = int(control)
                 #command = (MIDI_CONTROLLER_CHANGE & 0xf0) | (self.channel - 1 & 0xf)
                 #self.midi_out.send_message([command, channel & 0x7f, value & 0x7f])
 
-                msg = mido.Message(MIDO_CONTROLLER_CHANGE, channel=self.channel-1, control=control, value=value)
-                self.midi_out.send(msg)
+                for instrument in self.track.get_instruments_to_play():
+
+                    msg = mido.Message(MIDO_CONTROLLER_CHANGE, channel=instrument.channel-1, control=control, value=value)
+                    instrument.get_midi_out().send(msg)
 
 
-            if not (self.track.muted or self.instrument.muted or event.note.muted):
+            if not (self.track.muted or event.note.muted):
 
                 #print("%s ON: %s" % (self.track.name, event.note))
                 self.on_ct = self.on_ct + 1
                 self.player.inject_off_event(event)
-                msg = mido.Message(MIDO_NOTE_ON, note=note_number, velocity=velocity, channel=self.channel-1)
-                self.midi_out.send(msg)
+
+                for instrument in self.track.get_instruments_to_play():
+                    if not instrument.muted:
+                        msg = mido.Message(MIDO_NOTE_ON, note=_get_note_number(event.note, instrument), velocity=velocity, channel=instrument.channel-1)
+                        instrument.get_midi_out().send(msg)
 
         elif event.type == NOTE_OFF:
 
@@ -166,12 +184,13 @@ class RealtimeEngine(object):
 
             unregister_playing_note(self.track, event.on_event.note)
 
-            if self.track.muted or self.instrument.muted:
+            if self.track.muted:
                 return
 
             #print("OFF (%s): %s" % (self.on_ct, event.on_event.note))
             self.on_ct = self.on_ct - 1
-            #self.midi_out.send_message([ MIDI_NOTE_OFF | self.channel - 1, note_number, velocity])
 
-            msg = mido.Message(MIDO_NOTE_OFF, note=note_number, velocity=velocity, channel=self.channel-1)
-            self.midi_out.send(msg)
+            for instrument in self.track.get_instruments_to_play():
+                if not instrument.muted:
+                    msg = mido.Message(MIDO_NOTE_OFF, note=_get_note_number(event.note, instrument), velocity=velocity, channel=instrument.channel-1)
+                    instrument.get_midi_out().send(msg)
